@@ -46,8 +46,6 @@ from ceilometer import utils
 
 LOG = log.getLogger(__name__)
 
-CACHE_DURATION = 3600
-
 POLLING_OPTS = [
     cfg.StrOpt('cfg_file',
                default="polling.yaml",
@@ -154,10 +152,7 @@ class PollingTask(object):
 
         self.ks_client = self.manager.keystone
 
-        self.cache_client = cache_utils.get_client(
-            self.manager.conf,
-            expiration_time=CACHE_DURATION
-        )
+        self.cache_client = cache_utils.get_client(self.manager.conf)
 
     def add(self, pollster, source):
         self.pollster_matches[source.name].add(pollster)
@@ -169,9 +164,11 @@ class PollingTask(object):
             name = self.cache_client.get(uuid)
             if name:
                 return name
-            name = self.resolve_uuid_from_keystone(attr, uuid)
-            self.cache_client.set(uuid, name)
-            return name
+        # empty cache_client means either caching is not enabled or
+        # there was an error configuring cache
+        name = self.resolve_uuid_from_keystone(attr, uuid)
+        self.cache_client.set(uuid, name)
+        return name
 
         # Retrieve project and user names from Keystone only
         # if ceilometer doesn't have a caching backend
@@ -314,7 +311,8 @@ class AgentManager(cotyledon.Service):
                          for namespace in namespaces)
 
         # Create dynamic pollsters
-        extensions_dynamic_pollsters = self.create_dynamic_pollsters()
+        extensions_dynamic_pollsters = self.create_dynamic_pollsters(
+            namespaces)
 
         self.extensions = list(itertools.chain(*list(extensions))) + list(
             itertools.chain(*list(extensions_fb))) + list(
@@ -352,15 +350,18 @@ class AgentManager(cotyledon.Service):
         self._keystone = None
         self._keystone_last_exception = None
 
-    def create_dynamic_pollsters(self):
+    def create_dynamic_pollsters(self, namespaces):
         """Creates dynamic pollsters
 
         This method Creates dynamic pollsters based on configurations placed on
         'pollsters_definitions_dirs'
 
+        :param namespaces: The namespaces we are running on to validate if
+                           the pollster should be instantiated or not.
         :return: a list with the dynamic pollsters defined by the operator.
         """
 
+        namespaces_set = set(namespaces)
         pollsters_definitions_dirs = self.conf.pollsters_definitions_dirs
         if not pollsters_definitions_dirs:
             LOG.info("Variable 'pollsters_definitions_dirs' not defined.")
@@ -394,6 +395,21 @@ class AgentManager(cotyledon.Service):
 
             for pollster_cfg in pollsters_cfg:
                 pollster_name = pollster_cfg['name']
+                pollster_namespaces = pollster_cfg.get(
+                    'namespaces', ['central'])
+                if isinstance(pollster_namespaces, list):
+                    pollster_namespaces = set(pollster_namespaces)
+                else:
+                    pollster_namespaces = {pollster_namespaces}
+
+                if not bool(namespaces_set & pollster_namespaces):
+                    LOG.info("The pollster [%s] is not configured to run in "
+                             "these namespaces %s, the configured namespaces "
+                             "for this pollster are %s. Therefore, we are "
+                             "skipping it.", pollster_name, namespaces_set,
+                             pollster_namespaces)
+                    continue
+
                 if pollster_name not in pollsters_definitions:
                     LOG.info("Loading dynamic pollster [%s] from file [%s].",
                              pollster_name, pollsters_definitions_file)
